# AgroEcoMetrics

AgroEcoMetrics is a useful tool for manipulating agricultural and Ecological data

Source code:    (https://github.com/wiscbicklab/AgroEcoMetrics)

Bug reports:    (https://github.com/wiscbicklab/AgroEcoMetrics/issues)

Documentation:  (https://wiscbicklab.github.io/AgroEcoMetrics/)

It provides:
- Methods for calulating agricultural and ecological data
- Methods for manipulating and cleaning agriculture and ecological data
- Methods for visualizing agricultural and ecological data

